<?php

namespace Intergo\RabbitQueue\Queue;

use Illuminate\Contracts\Debug\ExceptionHandler;
use PhpAmqpLib\Channel\AMQPChannel;
use PhpAmqpLib\Exception\AMQPChannelClosedException;
use PhpAmqpLib\Exception\AMQPConnectionClosedException;
use Intergo\RabbitQueue\Queue\RabbitMQQueue as BaseRabbitMQQueue;

class IntergoRabbitMQQueue extends BaseRabbitMQQueue
{


    protected function publishBasic($msg, $exchange = '', $destination = '', $mandatory = false, $immediate = false, $ticket = null): void
    {
        try {
            parent::publishBasic($msg, $exchange, $destination, $mandatory, $immediate, $ticket);
        } catch (AMQPConnectionClosedException|AMQPChannelClosedException $exception) {
            app(ExceptionHandler::class)->report($exception);
            $this->reconnect();
            parent::publishBasic($msg, $exchange, $destination, $mandatory, $immediate, $ticket);
        }
    }

    protected function publishBatch($jobs, $data = '', $queue = null): void
    {
        try {
            parent::publishBatch($jobs, $data, $queue);
        } catch (AMQPConnectionClosedException|AMQPChannelClosedException $exception) {
            app(ExceptionHandler::class)->report($exception);
            $this->reconnect();
            parent::publishBatch($jobs, $data, $queue);
        }
    }

    protected function createChannel(): AMQPChannel
    {
        try {
            return parent::createChannel();
        } catch (AMQPConnectionClosedException|AMQPChannelClosedException $exception) {
            app(ExceptionHandler::class)->report($exception);
            $this->reconnect();
            return parent::createChannel();
        }
    }

}